import urllib.request as urlRequest
import urllib.parse as urlParse

url = "https://lichess.org/paste/"
values = {"pgn": '[White "1. platki 2.mleko"]\n[Black "1. mleko 2.platki"]\n\n1. f3 e5 2. g4 Qh4#'}

# pretend to be a chrome 47 browser on a windows 10 machine
headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.106 Safari/537.36"}

# encode values for the url
params = urlParse.urlencode(values).encode("utf-8")

# create the url
targetUrl = urlRequest.Request(url=url, data=params, headers=headers)

# open the url
x  = urlRequest.urlopen(targetUrl)

# read the response
respone = x.read()
print(respone)



#!/usr/bin/env python3
import chess
from engine import *
import os.path
import webbrowser

from flask import Flask, Response, request, render_template, url_for, jsonify
app = Flask(__name__) 

@app.route("/")
def hello():
  ret = open('index.html').read()
  return ret

@app.route("/info/<int:depth>/<path:fen>/") # routuj fen i depth do url tak zeby mozna bylo requestowac
def calc_move(depth, fen):
  print(f'depth: {depth}')
  engine = KoksSzachy(fen)
  move = engine.iter_deep(depth - 1)
  if move is None:
    print('Game over')
  else: 
    print(f'computer moves: {move}\n')
    return move

@app.route("/analysis", methods=['POST'])
def get_data():
  if request.method == 'POST':
    import json
    import urllib
    content = request.get_json() # {"content": ["1. f3 e5 2. g4 Qh4#"]}
    pgn = content['content'][0] # ['1. f3 e5 2. g4 Qh4#']
    pgn = {"pgn": pgn, "pgnFile": "", "analyse":"true"} # dwa ostatnie tak profilaktycznie
    url = f'https://lichess.org/paste?{urllib.parse.urlencode(pgn)}' # encode url zeby wstawic dane automatycznie
    print(url)
    webbrowser.open_new_tab(url)
    return '', 200 # musi cos zwracac
 
# for importing
def play():
  webbrowser.open_new_tab('http://localhost:5000')
  app.run(debug=True)

if __name__ == "__main__":
  app.run(debug=True)



import chess
import chess.pgn

board = chess.Board()
print(board.legal_moves)
print(board) # pokaz startowa pozycje
board.push_san("e4") # z mozliwych ruchow wybierz ten i go wykonaj
board.push_san("e5")
print('\n\n\n')
print(board) # pokaz pozycje figur po ruchach

print(board.legal_moves) # sprawdz czy mozliwe ruchy sie zmienily
print(board.pieces(chess.ROOK, chess.WHITE))
print(chess.pgn.Game())



import koksszachy
import sys

def my_help():
  mes = '''
  użycie: koksszachy [ARGUMENT]

  Lubisz grać w szachy? Podobał ci się chess.com lub lichess? W takim razie pokochasz KoksSzachy! <3
  Po więcej informacji odwiedź: https://github.com/a1eaiactaest/KoksSzachy

  argumenty:
  -h, --help    pokaż tą wiadomość
  -p, --play    zagraj w swoje ulubione szachy! 
  -d, --docs    przeczytaj dokumentację

  '''
  print(mes)

def main():
  try: 
    argument = sys.argv[1]
    if argument == '--play' or argument == '-p':
      koksszachy.play()

    if argument == '--docs' or argument == '-d':
      import webbrowser
      webbrowser.open_new_tab('https://github.com/a1eaiactaest/KoksSzachy/blob/main/README.md')

    if argument == '--help' or argument == '-h':
      my_help()

  except IndexError:
    my_help()
    return 0

if __name__ == '__main__':
  main()
